==> lxqt-panel-1.2.0.tar.xz: lxqt-panel-1.2.0/plugin-quicklaunch/translations/quicklaunch_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="224"/>
        <source>Drop Error</source>
        <translation>Slippfeil</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="225"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Filen/URLen &apos;%1&apos; kan ikke bli lagt til hurtigstarteren nå</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="331"/>
        <source>Drop application
icons here</source>
        <translation>Slipp program-
symboler her</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + DND)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Flytt til venstre</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Flytt til høyre</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Fjern fra hurtigstarteren</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="72"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.1.1.tar.xz: lxqt-panel-2.1.1/plugin-quicklaunch/translations/quicklaunch_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="229"/>
        <source>Drop Error</source>
        <translation>Slippfeil</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="230"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Filen/URLen &apos;%1&apos; kan ikke bli lagt til hurtigstarteren nå</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="336"/>
        <source>Drop application
icons here</source>
        <translation>Slipp program-
ikoner her</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + DND)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Flytt til venstre</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Flytt til høyre</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Fjern fra hurtigstarteren</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="72"/>
        <source>Refresh</source>
        <translation>Gjenoppfrisk</translation>
    </message>
</context>
</TS>
